ApiResponse<T> class

Generic API response wrapper for paginated and non-paginated data

Constructors

ApiResponse({required T? data, String? status, dynamic message, int? count, String? next, String? previous, T? results, int? currentPage, int? itemsPerPage, int? totalItems, bool? isLastPage})
ApiResponse.fromJson(Map<String, dynamic> json, T fromJsonT(Object? json))
factory

Properties

count int?
final
currentPage int?
final
data → T?
final
hashCode int
The hash code for this object.
no setterinherited
isLastPage bool?
final
itemsPerPage int?
final
message → dynamic
final
next String?
final
previous String?
final
results → T?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
totalItems int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(Object toJsonT(T value)) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited