ProductStatusData class

Product status data (from scan endpoint)

Constructors

ProductStatusData({String? name, String? displayMfgServingSize, String? displayNetWeight, double? natfirstScore, double? natfirstRating, String? iconFileName, bool? isFavorite, int? rewardPoints, bool? isSuspended})
ProductStatusData.fromJson(Map<String, dynamic> json)
factory

Properties

displayMfgServingSize String?
final
displayNetWeight String?
final
hashCode int
The hash code for this object.
no setterinherited
iconFileName String?
final
isFavorite bool?
final
isSuspended bool?
final
name String?
final
natfirstRating double?
final
natfirstScore double?
final
rewardPoints int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? displayMfgServingSize, String? displayNetWeight, double? natfirstScore, double? natfirstRating, String? iconFileName, bool? isFavorite, int? rewardPoints, bool? isSuspended}) ProductStatusData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited