TagDetails class

Detailed tag information model

Constructors

TagDetails({String? tag, String? name, String? generalInfo, String? causeReason, String? commonSymptopms, dynamic ingredients, dynamic ingredientPresent, dynamic ingredientAbsent, dynamic iconFileName, bool? hasInfo, String? tagType})
TagDetails.fromJson(Map<String, dynamic> json)
factory

Properties

causeReason String?
final
commonSymptopms String?
final
generalInfo String?
final
hashCode int
The hash code for this object.
no setterinherited
hasInfo bool?
final
iconFileName → dynamic
final
ingredientAbsent → dynamic
final
ingredientPresent → dynamic
final
ingredients → dynamic
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
final
tagType String?
final

Methods

copyWith({String? tag, String? name, String? generalInfo, String? causeReason, String? commonSymptopms, dynamic ingredients, dynamic ingredientPresent, dynamic ingredientAbsent, dynamic iconFileName, bool? hasInfo, String? tagType}) TagDetails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited