CameraView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CameraView
Constructors
-
CameraView({Key? key, required CustomPaint? customPaint, required dynamic onImage(InputImage inputImage), dynamic onCameraFeedReady(CameraController controller)?, VoidCallback? onDetectorViewModeChanged, dynamic onCameraLensDirectionChanged(CameraLensDirection direction)?, List<
Map< ? recentScans, CameraLensDirection initialCameraLensDirection = CameraLensDirection.back, dynamic onRegisterCallbacks(Function startCallback, Function stopCallback)?})String, dynamic> > -
const
Properties
- customPaint → CustomPaint?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialCameraLensDirection → CameraLensDirection
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onCameraFeedReady → dynamic Function(CameraController controller)?
-
final
- onCameraLensDirectionChanged → dynamic Function(CameraLensDirection direction)?
-
final
- onDetectorViewModeChanged → VoidCallback?
-
final
- onImage → dynamic Function(InputImage inputImage)
-
final
- onRegisterCallbacks → dynamic Function(Function startCallback, Function stopCallback)?
-
final
-
recentScans
→ List<
Map< ?String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CameraView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited