ExpertComment class

Constructors

ExpertComment({required int id, required String title, required dynamic imageFileName, required String comment, required String createdBy, required dynamic updatedBy, required String status, required List<String> products})
ExpertComment.fromJson(Map<String, dynamic> json)
factory

Properties

comment String
getter/setter pair
createdBy String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
imageFileName ↔ dynamic
getter/setter pair
products List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
title String
getter/setter pair
updatedBy ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited