IngredientItem class

Constructors

IngredientItem({required int id, required IngredientDetails ingredient, required String? displayText, required String? ingredientType, required int compOrderNo, int? parsedSeqNo, required String? product, required String? ingredientMasterTag, required int? score, required String? color, required String? concernText})
IngredientItem.fromJson(Map<String, dynamic> json)
factory

Properties

color String?
final
compOrderNo int
final
concernText String?
final
displayText String?
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
ingredient IngredientDetails
final
ingredientMasterTag String?
final
ingredientType String?
final
parsedSeqNo int?
final
product String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited