Product class

Constructors

Product({String? name, String? barcode, double? nutriScore, String? iconFileName, String? nutriGrade, Nutrients? nutrients, List? images, List<Tag>? tags, List<Tag>? topTags, List<IngredientElement>? ingredientsTags, List<ExpertComment>? expertComments, String? ingredientText, String? claimsInfo, String? allergensInfo, String? containsInfo, String? warningsInfo, String? netWeightUnit, dynamic novaScaleRating, dynamic hsrRating, double? netWeight, double? servingSize, String? servingSizeUnit, double? truthinServingSize, String? truthinServingSizeUnit, List? productReviewRatings, bool isFavorite = false, double? matchMeter, List<Tag>? ingredientTags, List<Tag>? valueTags, List<Tag>? goalTags, double? mfgServingSize, double? noOfServings, String? mmServingSizes, double? natfirstRating, String? displayNetWeight, String? displayMfgServingSize, List<IngredientItem>? ingredientItem, String? status, List<String>? categories, String? l3Category, HealthTagMetric? healthTagMetric, List<AllergenTag>? allergenTags, HealthQna? healthQNA, bool enableHCAlerts = false})
Product.fromJson(Map<String, dynamic> json)
factory

Properties

allergensInfo String?
final
allergenTags List<AllergenTag>?
final
barcode String?
final
categories List<String>?
final
claimsInfo String?
final
containsInfo String?
final
displayMfgServingSize String?
final
displayNetWeight String?
final
enableHCAlerts bool
getter/setter pair
expertComments List<ExpertComment>?
final
goalTags List<Tag>?
final
hashCode int
The hash code for this object.
no setterinherited
healthQNA HealthQna?
final
healthTagMetric HealthTagMetric?
final
hsrRating → dynamic
final
iconFileName String?
final
images List?
final
ingredientItem List<IngredientItem>?
final
ingredientsTags List<IngredientElement>?
final
ingredientTags List<Tag>?
final
ingredientText String?
final
isFavorite bool
getter/setter pair
l3Category String?
final
matchMeter double?
final
mfgServingSize double?
final
mmServingSizes String?
final
name String?
final
natfirstRating double?
final
netWeight double?
final
netWeightUnit String?
final
noOfServings double?
final
novaScaleRating → dynamic
final
nutrients Nutrients?
final
nutriGrade String?
final
nutriScore double?
final
productReviewRatings List?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servingSize double?
final
servingSizeUnit String?
final
status String?
final
tags List<Tag>?
final
topTags List<Tag>?
final
truthinServingSize double?
final
truthinServingSizeUnit String?
final
valueTags List<Tag>?
final
warningsInfo String?
final

Methods

copyWith({String? name, String? barcode, double? nutriScore, String? iconFileName, String? nutriGrade, Nutrients? nutrients, List<IngredientElement>? ingredientsTags, List<ExpertComment>? expertComments, List? images, List<Tag>? tags, List<Tag>? topTags, String? netWeightUnit, String? ingredientText, dynamic novaScaleRating, dynamic hsrRating, double? netWeight, double? servingSize, String? servingSizeUnit, double? truthinServingSize, String? truthinServingSizeUnit, List? productReviewRatings, bool? isFavorite, double? matchMeter, List<Tag>? ingredientTags, List<Tag>? valueTags, List<Tag>? goalTags, String? claimsInfo, String? allergensInfo, String? containsInfo, String? warningsInfo, double? mfgServingSize, double? noOfServings, String? mmServingSizes, String? displayNetWeight, String? displayMfgServingSize, double? natfirstRating, List<IngredientItem>? ingredientItem, List<String>? categories, String? l3Category, String? status, HealthTagMetric? healthTagMetric, List<AllergenTag>? allergenTags, HealthQna? healthQNA, bool? enableHCAlerts}) Product
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited