TruthinUITheme class abstract

Implementers

Constructors

TruthinUITheme()

Properties

accent1 Color
getter/setter pair
accent2 Color
getter/setter pair
accent3 Color
getter/setter pair
accent4 Color
getter/setter pair
alternate Color
getter/setter pair
alternate1 Color
getter/setter pair
bodyLarge TextStyle
no setter
bodyLargeFamily String
no setter
bodyMedium TextStyle
no setter
bodyMediumFamily String
no setter
bodySmall TextStyle
no setter
bodySmallFamily String
no setter
bodyText1 TextStyle
no setter
bodyText1Family String
no setter
bodyText2 TextStyle
no setter
bodyText2Family String
no setter
bright Color
getter/setter pair
customColor1 Color
getter/setter pair
customColor2 Color
getter/setter pair
customColor3 Color
getter/setter pair
customColor4 Color
getter/setter pair
customColor5 Color
getter/setter pair
customColor6 Color
getter/setter pair
customColor7 Color
getter/setter pair
customColor8 Color
getter/setter pair
customColor9 Color
getter/setter pair
displayLarge TextStyle
no setter
displayLargeFamily String
no setter
displayMedium TextStyle
no setter
displayMediumFamily String
no setter
displaySmall TextStyle
no setter
displaySmallFamily String
no setter
error Color
getter/setter pair
gras Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headlineLarge TextStyle
no setter
headlineLargeFamily String
no setter
headlineMedium TextStyle
no setter
headlineMediumFamily String
no setter
headlineSmall TextStyle
no setter
headlineSmallFamily String
no setter
highConcern Color
getter/setter pair
info Color
getter/setter pair
labelLarge TextStyle
no setter
labelLargeFamily String
no setter
labelMedium TextStyle
no setter
labelMediumFamily String
no setter
labelSmall TextStyle
no setter
labelSmallFamily String
no setter
lowConcern Color
getter/setter pair
moderateConcern Color
getter/setter pair
muted Color
getter/setter pair
primary Color
getter/setter pair
primaryBackground Color
getter/setter pair
primaryColor Color
no setter
primaryText Color
getter/setter pair
resendMessage Color
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
getter/setter pair
secondaryBackground Color
getter/setter pair
secondaryColor Color
no setter
secondaryText Color
getter/setter pair
severeConcern Color
getter/setter pair
shaded Color
getter/setter pair
shaded2 Color
getter/setter pair
shaded3 Color
getter/setter pair
subtitle1 TextStyle
no setter
subtitle1Family String
no setter
subtitle2 TextStyle
no setter
subtitle2Family String
no setter
success Color
getter/setter pair
tertiary Color
getter/setter pair
tertiaryColor Color
no setter
tinted Color
getter/setter pair
title1 TextStyle
no setter
title1Family String
no setter
title2 TextStyle
no setter
title2Family String
no setter
title3 TextStyle
no setter
title3Family String
no setter
titleLarge TextStyle
no setter
titleLargeFamily String
no setter
titleMedium TextStyle
no setter
titleMediumFamily String
no setter
titleSmall TextStyle
no setter
titleSmallFamily String
no setter
typography Typography
no setter
warning Color
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

deviceSize DeviceSize
getter/setter pair
themeMode ThemeMode
no setter

Static Methods

of(BuildContext context) TruthinUITheme