foodDescription property
String
get
foodDescription
Implementation
String get foodDescription {
switch (this) {
case 1:
return 'These are either unaltered or have undergone minimal processing, such as drying, boiling, freezing, or pasteurization. Examples include fresh fruits and vegetables, grains, legumes, meats, milk, and eggs.';
case 2:
return 'These are substances obtained from unprocessed or minimally processed foods or from nature and are used in the preparation of dishes and meals but are not consumed by themselves. Examples include oils, butter, sugar, and salt.';
case 3:
return 'These are relatively simple products made by adding sugar, oil, salt, or other processed culinary ingredients to unprocessed or minimally processed foods. Most have two or three ingredients. Examples include canned food, salted meat, and cheese.';
case 4:
return 'These are industrial formulations typically with five or more and usually many ingredients. Such ingredients often include those also used in processed foods, such as sugar, oils, fats, salt, anti-oxidants, stabilizers, and preservatives. Examples include soft drinks, packaged snacks, reconstituted meat products, and pre-prepared frozen dishes.';
default:
return 'Unknown';
}
}