showCategoryNotRatedDialog function
Implementation
void showCategoryNotRatedDialog(BuildContext context) {
popAlert(
context,
'Not Rated Yet, But We Can Still Help',
"Products like spices, infant foods, or supplements don't receive a TruthIn Rating because they serve specific nutritional needs. But where label data is available, we still show nutrient and ingredient insights to help you decide. ",
);
}