showRatingInProgressDialog function

void showRatingInProgressDialog(
  1. BuildContext context
)

Implementation

void showRatingInProgressDialog(BuildContext context) {
  popAlert(
    context,
    'Rating in Progress',
    'Our AI algorithms are diligently working to generate a rating for this product. We strive to offer precise and insightful ratings soon. Keep an eye on this space for updates.',
  );
}