ProductsService class
Products Service - wraps ProductsApi with BaseApi response handling
- Mixed-in types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAuthToken(
) → void - Clear auth token
-
getFullStatusOfProduct(
String barcode) → Future< GeneralResponse< ProductStatusResponse> > -
getProductDetail(
{required String barcode, String? l3category, String? source}) → Future< GeneralResponse< ProductDetails> > - Get product detail - Returns ProductDetails model
-
isProductExists(
String barcode) → Future< GeneralResponse< ProductDetails> > -
isProductExistsInLiveNew(
String barcode, {String type = 'food'}) → Future< GeneralResponse> -
loadResponse<
T> (Future< T> executor()) → Future<GeneralResponse< T> > -
Load response from API call and wrap it in GeneralResponse
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAuthToken(
String token) → void - Set auth token for authenticated requests
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRDA(
{required String barcode, required String servingSize}) → Future< GeneralResponse< PdaPanel> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited