ProductStatusResponse class
Product status response model (from scan endpoint)
Constructors
- ProductStatusResponse({String? status, dynamic message, ProductStatusData? data, String? objectStatus})
-
ProductStatusResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- data → ProductStatusData?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → dynamic
-
final
- objectStatus → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
Methods
-
copyWith(
{String? status, dynamic message, ProductStatusData? data, String? objectStatus}) → ProductStatusResponse -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited