IngredientElement class
Constructors
-
IngredientElement({required String? tag, required String? name, String? generalInfo, String? causeReason, String? commonSymptoms, List<
String> ? ingredients, String? ingredientPresent, String? ingredientAbsent, String? iconFileName, required bool? hasInfo, required String? tagType}) -
IngredientElement.fromJson(Map<
String, dynamic> json) -
factory
Properties
- causeReason → String?
-
final
- commonSymptoms → String?
-
final
- generalInfo → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInfo → bool?
-
final
- iconFileName → String?
-
final
- ingredientAbsent → String?
-
final
- ingredientPresent → String?
-
final
-
ingredients
→ List<
String> ? -
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
final
- tagType → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited