TruthInScanner class
Core initialization class
Properties
- apiKey → String
-
Get the configured API key
Throws an error if not initialized
no setter
- baseUrl → String?
-
Get the configured base URL
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
Check if TruthInScanner is initialized
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → TruthInScanner
-
Get the singleton instance
no setter
Static Methods
-
initialize(
{required String apiKey, String? baseUrl}) → void - Initialize TruthInScanner with API key
-
reset(
) → void - Reset the instance (useful for testing)